function JD = calen2jdn(year, month, day, hour, min, sec)

%CALEN2JDN converts the calendar date to Julian day number (JDN)
%
%OPTION 1:
%   SYNOPSIS
%      JD = calen2jdn(YEAR, MONTH, DAY, HOUR, MIN, SEC)
%   INPUT
%      Calendar date as YEAR, MONTH, DAY, HOUR, MIN, SEC
%   OUTPUT
%      JD - Julian Day in days
%
%OPTION 2: 
%   SYNOPSIS
%      JD = calen2jdn(DATEVEC)
%   INPUT
%      DATEVEC - date vector with columns (year,month,day,hour,min,sec)
%   OUTPUT
%      JD - vector of Julian Day in days
%
%   for details see http://en.wikipedia.org/wiki/Julian_day
%
%AUTHOR
%   Shantanu Desai (No longer part of the LV Collaboration)

%   $Id: calen2jdn.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

if(nargin == 1)
    [mRow,nCol] = size(year);
    if(nCol ~= 6)
        msgId = 'calen2jdn:tooFewInputs';
        error(msgId,'%s: date vector needs 6 columns!',msgId);
    end
    inData = year;
    year = inData(:,1);
    month = inData(:,2);
    day = inData(:,3);
    hour = inData(:,4);
    min = inData(:,5);
    sec = inData(:,6);
else
    if (nargin < 6)
        msgId = 'calen2jdn:tooFewInputs';
        error(msgId,'%s: # of inputs %d less than 6',msgId,nargin);
    end
end

a = floor((14 - month)/12);
Y = year + 4800 - a;
M = month + 12 * a - 3;

% For a date in the Gregorian calendar (at noon):
JDN = day + floor((153 * M + 2)/5) + 365 * Y + floor(Y/4) - ...
      floor(Y/100) + floor(Y/400) - 32045;

% Full Julian Date, not counting leap seconds
JD = JDN + (hour - 12)/24 + min/1440 + sec/86400;

return
