function dst = checkfordaylightsavings(yr,mo,day)

%CHECKFORDAYLIGHTSAVINGS - Checks if a given time falls in US DST
%
%SYNOPSIS
% DST = CHECKFORDAYLIGHTSAVINGS(YR,MO,DAY)
%
%INPUTS
%   YR - 4 digit year
%   MO - 2 digit month 
%   DAY - 1-2 digit day
%
%OUTPUT 
%   DST - (bool) true if daylight savings time is in effect, false otherwise
%
% This code is valid for dates between 2005 and 2015.
%
% The dates used in this code are from:
% http://eclipse.gsfc.nasa.gov/SEhelp/daylightsaving.html
%
%AUTHORS
%   Shantanu Desai (No longer part of the LV Collaboration)
%   Amber Stuver <amber.stuver@ligo.org>

%Id:$

% Check for errors

if yr < 2005 || yr > 2015
   error('checkfordaylightsavings : yr must be between 2005 and 2015.')
end

if mo < 1 || mo > 12
   error('checkfordaylightsavings : mo must be between 1 and 12.')
end

if day < 1 || day > 31
   error('checkfordaylightsavings : day must be between 1 and 31.')
end

inpDate = datenum(yr,mo,day); 

% Define start and stop dates for DST:

switch yr
 case 2005
   dstStartNum = datenum(2005,4,3);
   dstEndNum = datenum(2005,10,30) ;
 case 2006
   dstStartNum = datenum(2006,4,2);
   dstEndNum = datenum(2006,10,29) ;
 case 2007
    dstStartNum = datenum(2007,3,11);
    dstEndNum = datenum(2006,11,4);
 case 2008
    dstStartNum = datenum(2008,3,9);
    dstEndNum = datenum(2008,11,2);
 case 2009
    dstStartNum = datenum(2009,3,8);
    dstEndNum = datenum(2009,11,1);
 case 2010
    dstStartNum = datenum(2010,3,14);
    dstEndNum = datenum(2010,11,7);
 case 2011
    dstStartNum = datenum(2011,3,13);
    dstEndNum = datenum(2011,11,6);
 case 2012
    dstStartNum = datenum(2012,3,11);
    dstEndNum = datenum(2012,11,4);
 case 2013
    dstStartNum = datenum(2013,3,10);
    dstEndNum = datenum(2013,11,3);
 case 2014
    dstStartNum = datenum(2014,3,9);
    dstEndNum = datenum(2014,11,2);
 case 2015
    dstStartNum = datenum(2015,3,8);
    dstEndNum = datenum(2015,11,1);
 otherwise
    error('checkfordaylightsavings : Valid date ranges between 2005 and 2015!')
    return
end    

% Determine id DST

if ((dstStartNum <= inpDate) && (inpDate < dstEndNum))
   dst = false ;
else
   dst = true ;
end

return
