function [varargout] = logstairhist(varargin)

%LOGSTAIRHIST - Make stair-plot version of histogram on log scale
%
%OPTION 1:
%   SYNOPSIS
%      [FIGHAND,BINCNT,BINCTR] = logstairhist(Y,YMIN,YMAX,NBINS) 
%
%   INPUTS
%       Y - data to be histogrammed
%       YMIN - min value of Y in histogram
%       YMAX - max value of Y in histogram
%       NBINS - # of bins in histogram
%
%   OUTPUTS
%       FIGHAND - figure handle
%       BINCNT - # in each bin of histogram
%       BINCTR - center of each bin of histogram
%
%OPTION 2:
%   SYNOPSIS
%      [FIGHAND,STAIRCNT,STAIREDGE] = logstairhist(BINCTR,BINCNT[,PLTMIN]) 
%
%   INPUTS
%       BINCTR - center of each bin in histogram
%       BINCNT - # in each bin of histogram
%       PLTMIN - <optional> minimum of plot
%                <default = 0.1>
%   OUTPUTS
%       STAIRCNT - count at edge of stair
%       STAIREDGE - begining edge of stair
%       FIGHAND- figure handle
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: logstairhist.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% IF raw data and limits was input
%   GET histogram with defined limits, bins
% ENDIF
% - output of 'limhist' is for bin centers. For a stair 
% plot we need the beginning of each bin
% GET bin spacing
% SET bin start = bin center - (bin spacing/2)
% ADD extra termination bin
% SET value in termination bin = previous bin
% CREATE stair plot
if(nargin == 4)
    Y = varargin{1};
    ymin = varargin{2};
    ymax = varargin{3};
    nbins = varargin{4};
    [binCnt,binCtr] = limhist(Y,ymin,ymax,nbins);
    if(nargout > 1)
        varargout{2} = binCnt;
        if(nargout > 2)
            varargout{3} = binCtr;
        end
    end
    pltMin = 0.5;
elseif(nargin == 2)
    binCtr = varargin{1};
    binCnt = varargin{2};
    pltMin = 0.5;
elseif(nargin == 3)
    binCtr = varargin{1};
    binCnt = varargin{2};
    pltMin = varargin{3};
else
    msgId = 'logstairhist:badInput';
    error(msgId,'%s: wrong number of inputs');
end
stairCnt = binCnt;
binSpace = binCtr(2) - binCtr(1);
stairEdge = binCtr - (binSpace/2);
numEdges = numel(stairEdge);
stairEdge(numEdges+1) = stairEdge(numEdges) + binSpace;
stairCnt(numEdges+1) = stairCnt(numEdges);
% for log scale we wnat full bin lines
%  - set min value to 1/5 * low edge of plot scale
%  - set low edge of plot on log scale
minStair = pltMin / 5;
stairCnt = max(stairCnt,minStair);
if(nargin == 2)
    if(nargout > 1)
        varargout{2} = stairCnt;
        if(nargout > 2)
            varargout{3} = stairEdge;
        end
    end
end
figHand = stairs(stairEdge,stairCnt,'b-','LineWidth',3);
if(nargout > 0)
    varargout{1} = figHand;
end
hold on;
axeVect = axis;
axeVect(3) = pltMin;
set(gca,'YScale','log');
%
% - we also want to scale plot correctly
%   so set the top to 2*max bin
% - make sure the X axes stay fixed
hold on;
maxCount = max(stairCnt)*2;
axeVect = axis;
yMax = max(axeVect(4),maxCount);
axeVect(4) = yMax;
axeVect(1) = stairEdge(1);
axeVect(2) = stairEdge(end);
axis(axeVect);
hold off;
return
