function chisquare = sigmoidchisquare(fitParameters, amplitude, efficiency, ...
                                      efficiencyError)
%SIGMOIDCHISQUARE Test quality of sigmoid function fit to real data.
%
%SYNOPSIS
%   chisquare = sigmoidchisquare(fitParameters, amplitude, efficiency, ...
%                                     efficiencyError)
%
%INPUTS
%   fitParameters      vector of fit parameters (see below)
%   amplitude          vector of injection amplitudes
%   efficiency         vector of measured efficiencies
%   efficiencyError    vector of estimated efficiency errors
%
%OUTPUTS
%   chisquare          resulting chi-square value of fit
%
% The fitParameters vector contains the following parameters
%
%   fitParameters(1)   sigmoidCenter    amplitude at fifty percent efficiency
%   fitParameters(2)   sigmoidWidth     decade width parameter of sigmoid curve
%   fitParameters(3)   sigmoidPedestal  pedestal of sigmoid curve
%
% This is a helper function of SIGMOIDFIT and should not be called directly.
%
% See also SIGMOID and SIGMOIDFIT.
%
%AUTHOR
% Lindy L. Blackburn <lindy.blackburn@ligo.org>
% Shourov K. Chatterji (No longer in the LV Collaboration)

% $Id: sigmoidchisquare.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% extract fit parameters
sigmoidCenter = fitParameters(1);
sigmoidWidth = fitParameters(2);
sigmoidAsymmetry = fitParameters(3);
sigmoidPedestal = fitParameters(4);
sigmoidEntablature = fitParameters(5);

% compute sigmoid function
fitEfficiency = sigmoid(amplitude, sigmoidCenter, sigmoidWidth, ...
                        sigmoidAsymmetry, sigmoidPedestal, ...
                        sigmoidEntablature);

% determine chi square value of fit
chisquare = sum(((fitEfficiency - efficiency) ./ efficiencyError).^2);

% constrain fit parameters
if sigmoidWidth <= 0,
  chisquare = Inf;
end
if (sigmoidAsymmetry <= -1) || (sigmoidAsymmetry > 0),
  chisquare = Inf;
end
if (sigmoidPedestal < 0) || (sigmoidPedestal > 1),
  chisquare = Inf;
end
if (sigmoidEntablature < 0) || (sigmoidEntablature > 1),
  chisquare = Inf;
end
