function high = OneSidedLimit(n,bkg,conflevel)

%ONESIDEDLIMIT - frequentist upper limit for Poisson process with background
%
%SYNOPSIS
%   HIGH = OneSidedLimit(N, BKG, CONFLEVEL)
%
%INPUTS
%   N - number of events
%   BKG - expected mean background
%   CONFLEVEL - 1 - prob. of getting N or fewer events
%
%OUTPUT
%   HIGH = Poisson mean mu
%
%AUTHOR
%   Peter Shawhan <peter.shawhan@ligo.org>

% $Id: OneSidedLimit.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

  %-- if conflevel is 0.9 and the number count is reasonably small,
  %-- use a lookup table
  if conflevel==0.9 && n<=20
    lookup90 = [2.302585065364838, 3.889720190717521, 5.322320313514647,...
                6.680783092975617, 7.993589648781540, 9.274673879916037,...
                10.53207209223307, 11.77091442827035, 12.99471154808998,...
                14.20599038442926, 15.40664114004314, 16.59812215015929,...
                17.78158558375289, 18.95796131237398, 20.12801190963322,...
                21.29237252473831, 22.45157878246099, 23.60608689928046,...
                24.75628997195940, 25.90252855956409, 27.04510120010132];
    mu = lookup90(n+1);

  else
    %-- Find the solution iteratively by bisection.
    %-- Is there a better way???

    alpha = 1 - conflevel;

    %-- Initial guess and step
    mu = n;
    step = sqrt(n+1);
    lastsign = +1;

    %-- Now loop
    while abs(step) > 0.0000001
      prob = poisscdf(n,mu);
      newsign = sign(prob-alpha);
      if newsign*lastsign == -1
        %-- We've bracketed the value
        step = -0.5 * step;
      end
      %-- Take the next step
      lastsign = newsign;
      mu = mu + step;
    end

  end

  high = mu - bkg;

return
